@@ -22,8 +22,9 @@ logging.getLogger("biocommons.seqrepo.seqaliasdb.seqaliasdb").setLevel(logging.I
 logging.getLogger("biocommons.seqrepo.fastadir.fastadir").setLevel(logging.INFO)  # noqa: E501
 
 
-SEQREPO_DATA_PATH = environ.get("SEQREPO_DATA_PATH",
-                                "/usr/local/share/seqrepo/latest")
+SEQREPO_ROOT_DIR = Path(
+    environ.get("SEQREPO_ROOT_DIR", "/usr/local/share/seqrepo/latest")
+)
 
 
 class DownloadException(Exception):
@@ -34,8 +35,8 @@ class DownloadException(Exception):
         super().__init__(*args, **kwargs)
 
 
-from gene.schemas import SourceName, NamespacePrefix, SourceIDAfterNamespace, ItemTypes  # noqa: E402, E501
-ITEM_TYPES = {k.lower(): v.value for k, v in ItemTypes.__members__.items()}
+from gene.schemas import SourceName, NamespacePrefix, SourceIDAfterNamespace, RefType  # noqa: E402, E501
+ITEM_TYPES = {k.lower(): v.value for k, v in RefType.__members__.items()}
 
 # Sources we import directly (HGNC, Ensembl, NCBI)
 SOURCES = {source.value.lower(): source.value
