@@ -1,14 +1,18 @@
 """This module defines the Ensembl ETL methods."""
 import logging
+from pathlib import Path
 import re
 from ftplib import FTP
+from typing import Dict, List
+from biocommons.seqrepo import SeqRepo
 
 import gffutils
+from gffutils.feature import Feature
 
 from .base import Base
 from gene import APP_ROOT
 from gene.schemas import SourceName, NamespacePrefix, Strand, SourceMeta
-from gene.database import Database
+from gene.database import AbstractDatabase
 from gene.etl.vrs_locations import SequenceLocation
 
 
@@ -19,20 +23,18 @@ logger.setLevel(logging.DEBUG)
 class Ensembl(Base):
     """ETL the Ensembl source into the normalized database."""
 
-    def __init__(self, database: Database, host="ftp.ensembl.org",
-                 data_dir="pub/current_gff3/homo_sapiens/",
-                 src_data_dir=APP_ROOT / "data" / "ensembl") -> None:
+    def __init__(self, database: AbstractDatabase, host: str = "ftp.ensembl.org",
+                 data_dir: str = "pub/current_gff3/homo_sapiens/",
+                 src_data_dir: Path = APP_ROOT / "data" / "ensembl") -> None:
         """Initialize Ensembl ETL class.
 
-        :param Database database: DynamoDB database
-        :param str host: FTP host name
-        :param str data_dir: FTP data directory to use
-        :param Path src_data_dir: Data directory for Ensembl
+        :param database: DynamoDB database
+        :param host: FTP host name
+        :param data_dir: FTP data directory to use
+        :param src_data_dir: Data directory for Ensembl
         """
         super().__init__(database, host, data_dir, src_data_dir)
         self._sequence_location = SequenceLocation()
-        self._host = host
-        self._data_dir = data_dir
         self._version = None
         self._fn = None
         self._data_url = None
@@ -55,7 +57,7 @@ class Ensembl(Base):
                     self._assembly = resp["assembly"]
                     self._version = resp["version"]
                     self._fn = f
-                    self._data_url = f"ftp://{self._host}/{self._data_dir}{self._fn}"
+                    self._data_url = f"ftp://{self._host}/{self._data_dir}{self._fn}"  # noqa: E501
                     new_fn = f"ensembl_{self._version}.gff3"
                     if not (self.src_data_dir / new_fn).exists():
                         self._ftp_download_file(ftp, self._fn, self.src_data_dir,
@@ -89,26 +91,23 @@ class Ensembl(Base):
         for item in db.features_of_type("chromosome"):
             accession_numbers[item[0]] = item[8]["Alias"][-1]
 
-        with self._database.genes.batch_writer() as batch:
-            for f in db.all_features():
-                if f.attributes.get("ID"):
-                    f_id = f.attributes.get("ID")[0].split(":")[0]
-                    if f_id == "gene":
-                        gene = \
-                            self._add_gene(f, self.seqrepo, accession_numbers)
-                        if gene:
-                            self._load_gene(gene, batch)
+        for f in db.all_features():
+            if f.attributes.get("ID"):
+                f_id = f.attributes.get("ID")[0].split(":")[0]
+                if f_id == "gene":
+                    gene = \
+                        self._add_gene(f, self.seqrepo, accession_numbers)
+                    if gene:
+                        self._load_gene(gene)
         logger.info("Successfully transformed Ensembl.")
 
-    def _add_gene(self, f, sr, accession_numbers):
+    def _add_gene(self, f: Feature, sr: SeqRepo, accession_numbers: Dict) -> Dict:
         """Create a transformed gene record.
 
-        :param gffutils.feature.Feature f: A gene from the data
-        :param SeqRepo sr: Access to the seqrepo
-        :param dict accession_numbers: Accession numbers for each
-            chromosome and scaffold
-        :return: A gene dictionary if the ID attribute exists.
-                 Else return None.
+        :param f: A gene from the data
+        :param sr: Access to the seqrepo
+        :param accession_numbers: Accession numbers for each chromosome and scaffold
+        :return: A gene dictionary containing data if the ID attribute exists.
         """
         gene = dict()
         if f.strand == "-":
@@ -128,10 +127,10 @@ class Ensembl(Base):
 
         return gene
 
-    def _add_attributes(self, f, gene):
+    def _add_attributes(self, f: Feature, gene: Dict) -> None:
         """Add concept_id, symbol, xrefs, and associated_with to a gene record.
 
-        :param gffutils.feature.Feature f: A gene from the data
+        :param f: A gene from the data
         :param gene: A transformed gene record
         """
         attributes = {
@@ -162,7 +161,7 @@ class Ensembl(Base):
                         src_id = val.split("Acc:")[-1].split("]")[0]
                         if ":" in src_id:
                             src_id = src_id.split(":")[-1]
-                        source = self._get_xref_associated_with(src_name, src_id)  # noqa: E501
+                        source = self._get_xref_associated_with(src_name, src_id)
                         if "xrefs" in source:
                             gene["xrefs"] = source["xrefs"]
                         elif "associated_with" in source:
@@ -171,23 +170,25 @@ class Ensembl(Base):
 
                 gene[attributes[key]] = val
 
-    def _add_location(self, f, gene, sr, accession_numbers):
+    def _add_location(
+        self, f: Feature, gene: Dict, sr: SeqRepo, accession_numbers: Dict
+    ) -> Dict:
         """Add GA4GH SequenceLocation to a gene record.
         https://vr-spec.readthedocs.io/en/1.1/terms_and_model.html#sequencelocation
 
-        :param gffutils.feature.Feature f: A gene from the data
-        :param dict gene: A transformed gene record
-        :param dict accession_numbers: Accession numbers for each chromosome
-            and scaffold
-        :param  SeqRepo sr: Access to the seqrepo
+        :param f: A gene from the data
+        :param gene: A transformed gene record
+        :param sr: Access to the seqrepo
+        :param accession_numbers: Accession numbers for each chromosome and scaffold
+        :return: gene record dictionary with location added
         """
         return self._sequence_location.add_location(accession_numbers[f.seqid],
                                                     f, gene, sr)
 
-    def _get_xref_associated_with(self, src_name, src_id):
+    def _get_xref_associated_with(self, src_name: str, src_id: str) -> Dict:
         """Get xref or associated_with concept.
 
-        :param str src_name: Source name
+        :param src_name: Source name
         :param src_id: The source's accession number
         :return: A dict containing an other identifier or xref
         """
@@ -199,14 +200,14 @@ class Ensembl(Base):
             source["xrefs"] = \
                 [f"{NamespacePrefix.NCBI.value}:{src_id}"]
         elif src_name.startswith("UniProt"):
-            source["associated_with"] = [f"{NamespacePrefix.UNIPROT.value}:{src_id}"]  # noqa: E501
+            source["associated_with"] = [f"{NamespacePrefix.UNIPROT.value}:{src_id}"]
         elif src_name.startswith("miRBase"):
-            source["associated_with"] = [f"{NamespacePrefix.MIRBASE.value}:{src_id}"]  # noqa: E501
+            source["associated_with"] = [f"{NamespacePrefix.MIRBASE.value}:{src_id}"]
         elif src_name.startswith("RFAM"):
-            source["associated_with"] = [f"{NamespacePrefix.RFAM.value}:{src_id}"]  # noqa: E501
+            source["associated_with"] = [f"{NamespacePrefix.RFAM.value}:{src_id}"]
         return source
 
-    def perform_etl(self, *args, **kwargs):
+    def perform_etl(self, *args, **kwargs) -> List[str]:
         """Extract, Transform, and Load data into DynamoDB database.
 
         :return: Concept IDs of concepts successfully loaded
@@ -215,10 +216,10 @@ class Ensembl(Base):
         self._extract_data()
         self._add_meta()
         self._transform_data()
-        self._database.flush_batch()
+        self._database.complete_write_transaction()
         return self._processed_ids
 
-    def _add_meta(self, *args, **kwargs):
+    def _add_meta(self, *args, **kwargs) -> None:
         """Add Ensembl metadata."""
         metadata = SourceMeta(
             data_license="custom",
@@ -235,17 +236,4 @@ class Ensembl(Base):
             genome_assemblies=[self._assembly]
         )
 
-        self._database.metadata.put_item(
-            Item={
-                "src_name": SourceName.ENSEMBL.value,
-                "data_license": metadata.data_license,
-                "data_license_url": metadata.data_license_url,
-                "version": metadata.version,
-                "data_url": metadata.data_url,
-                "rdp_url": metadata.rdp_url,
-                "data_license_attributes": metadata.data_license_attributes,
-                "genome_assemblies": metadata.genome_assemblies
-            }
-        )
-
-        self._load_meta(self._database, metadata, SourceName.ENSEMBL.value)
+        self._database.add_source_metadata(self._src_name, metadata)
